( cd opt/kde/lib ; rm -rf libk3bdevice.so.6 )
( cd opt/kde/lib ; ln -sf libk3bdevice.so.6.0.0 libk3bdevice.so.6 )
( cd opt/kde/lib ; rm -rf libk3bdevice.so )
( cd opt/kde/lib ; ln -sf libk3bdevice.so.6 libk3bdevice.so )
( cd opt/kde/lib ; rm -rf libk3blib.so.6 )
( cd opt/kde/lib ; ln -sf libk3blib.so.6.0.0 libk3blib.so.6 )
( cd opt/kde/lib ; rm -rf libk3blib.so )
( cd opt/kde/lib ; ln -sf libk3blib.so.6 libk3blib.so )
#%% begin initialize k3b-2.0.1
/bin/bash /opt/kde/bin/plamo_update_kde.sh
#%% end
